Learn R Programming

emplikAUC (version 0.5)

EL2paucT1T2: Testing one pAUC(p1, p2) and two quantile values together by Empirical Likelihood.

Description

This function computes the two sample Log Empirical Likelihood ratio for testing \(H_0\): pAUC(p1, p2) = theta; F(tau1)=1-p2; F(tau2)= 1-p1. The two samples are in the x-vector and y-vector.

Usage

EL2paucT1T2(tauVec, pauc, partial1, partial2, x, y, epsxy)

Value

A single value that is the "-2LLR" from emplik2::el2.cen.EMm(). Typically should be distributed as chi square df=3, under \(H_0\).

Arguments

tauVec

The vector (tau1, tau2), the two quantile values, to be tested.

pauc

The value of the pAUC(p1, p2) under \(H_0\), to be tested.

partial1

The probability that define the quantile 1

partial2

The probability that define the quantile 2. Must satisfy partial 1 < partial 2 .

x

a vector of observations, length m, for the first sample.

y

a vector of observations, length n, for the second sample.

epsxy

The parameter for smoothing when compare x-y.

Author

Mai Zhou <maizhou@gmail.com>.

Details

The input tauVec=(tau1, tau2), and must have: tau1 < tau2. The relavant definitions are: tau1 = \(F^{-1}\)(1-partial2); tau2 = \(F^{-1}\)(1-partial1). Thus, we must have partial2 > partial1.

This function is testing 3 parameters simultanuously. It depend on the package emplik2.

The empirical likelihood we used here is defined as $$ EL = \prod_{i=1}^m v_i \prod_{j=1}^n \nu_j ~;~~~s.t. ~~~~~ \sum v_i =1 ~,~~ \sum \nu_j =1 ~. $$

References

Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood. Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf

Examples

Run this code
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)

Run the code above in your browser using DataLab