Learn R Programming

emplikAUC (version 0.5)

New.el2.test: One Iteration of Computing Paired Two Sample Constrained NPMLE.

Description

This function computes the two sample Constrained Data NPMLE: u vectoe and v vector.

Usage

New.el2.test(u0, v0, indicmat, tol.H0, step=0.001)

Value

A list that is the same as el2.cen.EMs() from emplik2 package. Which contains

u

The new constrained NPMLE. X sample.

v

The new constrained NPMLE. Y sample.

lam

The lambda value.

Arguments

u0

The constrained NPMLE from initial probability for sample one.

v0

given constrained NPMLE, initial probability for sample two

indicmat

A Matrix of (smoothed) indicator values: I[x[i] < y[j]] - theta.

tol.H0

a positive number for solve constrained NPMLE tolerance.

step

a positive number. Used to approximate the dirivative of lambda function at 0.

Author

Mai Zhou <maizhou@gmail.com>.

Details

The constraint is specified by matrix indicmat in $$ u \%*\% indicmat \%*\% t(v) = 0 $$

The empirical likelihood we used here is defined as $$ EL = \prod_{i=1}^m v_i \prod_{j=1}^n \nu_j ~;~~~~~ \sum v_i =1 ~,~~ \sum \nu_j =1 ~. $$

References

Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood. Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf

Examples

Run this code
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)

Run the code above in your browser using DataLab