This function computes the two sample Log Empirical Likelihood ratio for testing \(H_0\): pAUC(0, p) = theta. The two samples are in the x-vector and y-vector.
eltest4paucONE(theta,x,y,nuilow,nuiup,ind,partial,epsxy=0.05,epsT=(length(x))^(-0.75))A list containing
The -2 log empirical likelihood ratio.
The nuisance parameter value to achieve the minimum.
The p-value.
The "true" value of the pAUC under \(H_0\), to be tested.
a vector of observations, length m, for the first sample. Test-results with healthy subjects.
a vector of observations, length n, for the second sample. Test-results with desease subjects.
The lower bound for the nuisance parameter (the (1-p)-th quantile of X CDF F) search.
The upper bound for the nuisance parameter search.
A smoothed indicator function, to generate a Matrix of (smoothed) indicator values: I[x[i] < y[j]].
The probability p in the pAUC(0,p).
Window width for the smoother, "ind", when compare x-y.
Window width for the smoother, "ind", when define quantile.
Mai Zhou <maizhou@gmail.com>.
This function calls the function eltest4paucT.
We then use optimize( ) to profile out the nuisance parameter.
Return an empirical likelihood ratio siutable for testing one parameter pAUC(0,p).
The empirical likelihood we used here is defined as $$ EL = \prod_{i=1}^m v_i \prod_{j=1}^n \nu_j ~;~~~~~~ \sum v_i =1 ~,~~ \sum \nu_j =1 ~. $$
Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood. Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)
Run the code above in your browser using DataLab