This function computes the two sample Log Empirical Likelihood ratio for testing \(H_0\): pAUC(0,p) = theta and F(tau) = 1-p. The two samples are in the x-vector and y-vector.
eltest4paucT(tau, x, y, true, ind, epsxy, epsT, tol.u, tol.v, tol.H0, p)A list containing
The final tilting parameter.
the new u vector.
The new v vector.
The -2 log empirical likelihood ratio.
The iteration number used in computing.
The "true" value of the (1-p)th quantile of X, under \(H_0\), to be tested.
a vector of observations, length m, for the first sample. Test-results with healthy subjects.
a vector of observations, length n, for the second sample. Test-results with desease subjects.
The \(H_0\) value of the pAUC(0, p) to be tested.
A smoothed indicator function, to generate a Matrix of (smoothed) indicator values: I[x[i] < y[j]].
Window width for smoother (ind) when compare x-y.
Window width for smoother (ind) when find quantile.
Error tol for final u probability vector. Must > 0.
Error tol for final v probability vector. Must > 0.
The error bound for checking if the constrained NPMLE satisfy H0, must >0.
The probability p in pAUC(0, p), and also in F(tau) = 1-p.
Mai Zhou <maizhou@gmail.com>.
This function is similar to el2testPaucT( ). Just a different algorithm (not EM).
Speed and convergence may be slightly different.
This function is called by eltest4paucONE.
It is listed here because the user may find it useful elsewhere.
The empirical likelihood we used here is defined as $$ EL = \prod_{i=1}^m v_i \prod_{j=1}^n \nu_j ~;~~~~~~ \sum v_i =1 ~,~~ \sum \nu_j =1 ~. $$
Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood. Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)
Run the code above in your browser using DataLab