Learn R Programming

emplikAUC (version 0.5)

emplikAUC.internal: Internal emplikAUC functions

Description

These are internal functions called by eltest4aucONE and eltest4paucT. They are not intended to be called by users.

Usage

lamONE(u0, v0, indicmat, tol.H0)
lam2(u0, v0, indicmat1, indicmat2, tol.H0, start)

Value

Output is a list containing:

u

the new u vector.

v

the new v vector.

lam

The solution lambda.

Arguments

u0

a vector of probabilities, length m, for the first (X) sample.

v0

a vector of propabilities, length n, for the second (Y) sample.

indicmat

a Matrix (size m by n) of indicator function values: I[X[i] < Y[j]], But typically smoothed and centered.

tol.H0

The error bound for (checking) if satisfy \(H_0\), must > 0.

Details

lamONE() find the lambda (tilting parameter) in the two sample Empirical Likelihood, with an AUC constrain.

This function computes the lambda that satisfy null hypothesis \(H_0\) constraint by using uniroot.

This function is called by eltest4aucONE. It is listed here because the user may find it useful elsewhere.

The function lam2, similar to function lamONE, calculates the tilting parameters (lam1, lam2) for the empirical likelihood of a joint hypothesis about pAUC(0, p) = theta and F(tau) = p.

The indicmat1, indicmat2 should reflect the joint hypothesis, in the U-stat fashion.

The function lam2( ) is called by eltest4paucT( ), and is similar to lamONE except there are 2 lambda's and needs to call multiroot() to solve the equation.

And also, with a starting value input to help the iterations of solving the equation. It (start) is directly passed to multiroot( ) function.

Author: Ding Xue.