findULNEW: Finding the Upper and Lower bound of a confidence interval for theta by repeatedly testing the
hypothesis for the parameter theta.
Description
This function try to find the Upper and Lower bound of a confidence interval
by repeatedly testing the
hypothesis for the parameter theta until we reach the
given level for the "-2LLR" which is returned from
the user supplied function fun.
The final likelihood ratio value for Lower bound. Should = level.
Uvalue
The final likelihood ratio value for Upper bound. Should = level.
Arguments
step
Search step. Must > 0.
initStep
The initial step from MLE. May be used if we knew the bound is far away from MLE. This help
to speed up things. Should be >=0.
fun
The function that should return "-2LLR".
MLE
The MLE of the parameter.
level
The level of the confidence. Default to 3.84 which is 95 percent confidence (assume df=1).
tol
The error bound for achieving the level given.
...
Any additional input to be passed to fun.
Author
Mai Zhou <maizhou@gmail.com>.
Details
This function just combines the two functions findUnew( ) and findLnew( ).
References
Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood.
Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf