A list that is the same as el2.cen.EMs() from emplik2 package.
Which contains
u
The new constrained NPMLE. X sample.
v
The new constrained NPMLE. Y sample.
lam
The lambda value.
Arguments
u0
The constrained NPMLE from initial probability for sample one.
v0
given constrained NPMLE, initial probability for sample two
indicmat
A Matrix of (smoothed) indicator values: I[x[i] < y[j]] - theta.
tol.H0
a positive number for solve constrained NPMLE tolerance.
step
a positive number. Used to approximate the dirivative of lambda function at 0.
Author
Mai Zhou <maizhou@gmail.com>.
Details
The constraint is specified by matrix indicmat in
$$ u \%*\% indicmat \%*\% t(v) = 0 $$
The empirical likelihood we used here is defined as
$$ EL = \prod_{i=1}^m v_i \prod_{j=1}^n \nu_j ~;~~~~~ \sum v_i =1 ~,~~ \sum \nu_j =1 ~. $$
References
Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood.
Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf