smooth0: Non-Smoothed indicator function 0.5I[x=y] + I[x < y].
Description
This function computes the non-smoothed Indicator function 0.5I[x=y] + I[x < y].
Usage
smooth0(x, y)
Value
smooth0( ) returns a matrix of dimension ncol=length(y), nrow=length(x). The entry
of the matrix are values of 0.5I[x[i] = y[j]] + I[x[i] < y[j]].
Arguments
x
a vector of observations, length m, for the first sample.
y
a vector of observations, length n, for the second sample.
Author
Mai Zhou <maizhou@gmail.com>.
Details
This function is used in the original AUC computation (non-smoothed).
You may achieve the same result with a (data dependent) small eps in the function smooth3(x,y,eps).
But this is faster and no eps to worry about.
It is listed here because users may find it useful.
References
Zhao, Y., Ding, X. and Zhou (2021). Confidence Intervals of AUC and pAUC by Empirical Likelihood.
Tech Report. https://www.ms.uky.edu/~mai/research/eAUC1.pdf